documentationtools.Documenter
=============================

.. abjad-lineage:: abjad.tools.documentationtools.Documenter.Documenter.Documenter

.. autoclass:: abjad.tools.documentationtools.Documenter.Documenter.Documenter
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.module_name
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.object
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.prefix
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__call__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__ge__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__gt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__le__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__lt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.Documenter.__repr__
   :noindex:
